==> core-react-0.1.7.tgz: package/README.md <==
<!-- PIGEONPOSSE START MARK -->
<!--
██████╗ ██╗ ██████╗ ███████╗ ██████╗ ███╗   ██╗  
██╔══██╗██║██╔════╝ ██╔════╝██╔═══██╗████╗  ██║  
██████╔╝██║██║  ███╗█████╗  ██║   ██║██╔██╗ ██║  
██╔═══╝ ██║██║   ██║██╔══╝  ██║   ██║██║╚██╗██║  
██║     ██║╚██████╔╝███████╗╚██████╔╝██║ ╚████║  
╚═╝     ╚═╝ ╚═════╝ ╚══════╝ ╚═════╝ ╚═╝  ╚═══╝  
                                                 
██████╗  ██████╗ ███████╗███████╗███████╗        
██╔══██╗██╔═══██╗██╔════╝██╔════╝██╔════╝        
██████╔╝██║   ██║███████╗███████╗█████╗          
██╔═══╝ ██║   ██║╚════██║╚════██║██╔══╝          
██║     ╚██████╔╝███████║███████║███████╗        
╚═╝      ╚═════╝ ╚══════╝╚══════╝╚══════╝        
                                                 
                                                 
                                                 
█████╗█████╗█████╗█████╗█████╗█████╗█████╗       
╚════╝╚════╝╚════╝╚════╝╚════╝╚════╝╚════╝       
                                                 
                                                 
                                                 
███████╗██╗   ██╗██████╗ ███████╗██████╗  █████╗ 
██╔════╝██║   ██║██╔══██╗██╔════╝██╔══██╗██╔══██╗
███████╗██║   ██║██████╔╝█████╗  ██████╔╝╚█████╔╝
╚════██║██║   ██║██╔═══╝ ██╔══╝  ██╔══██╗██╔══██╗
███████║╚██████╔╝██║     ███████╗██║  ██║╚█████╔╝
╚══════╝ ╚═════╝ ╚═╝     ╚══════╝╚═╝  ╚═╝ ╚════╝ 
                                                                     
                                                
REPOSITORY: https://github.com/pigeonposse/super8
AUTHORS: 
	- Angelo (https://pigeonposse.com)

DEVELOPED BY Angelo 🐦🌈

-->
<!-- PIGEONPOSSE END MARK -->

# SUPER8 | Core & Components _(React)_

<!-- PIGEONPOSSE START HEADER -->

[![HEADER](https://raw.githubusercontent.com/pigeonposse/super8/main/docs/images/banner.png)](https://super8.pigeonposse.com/)

[![Web](https://img.shields.io/badge/Web-grey?style=for-the-badge&logoColor=white)](https://pigeonposse.com)
[![About Us](https://img.shields.io/badge/About%20Us-grey?style=for-the-badge&logoColor=white)](https://pigeonposse.com?popup=about)
[![Donate](https://img.shields.io/badge/Donate-pink?style=for-the-badge&logoColor=white)](https://pigeonposse.com/?popup=donate)
[![Github](https://img.shields.io/badge/Github-black?style=for-the-badge&logo=github&logoColor=white)](https://github.com/pigeonposse)
[![Twitter](https://img.shields.io/badge/Twitter-black?style=for-the-badge&logo=twitter&logoColor=white)](https://twitter.com/pigeonposse_)
[![Instagram](https://img.shields.io/badge/Instagram-black?style=for-the-badge&logo=instagram&logoColor=white)](https://www.instagram.com/pigeon.posse/)
[![Medium](https://img.shields.io/badge/Medium-black?style=for-the-badge&logo=medium&logoColor=white)](https://medium.com/@pigeonposse)

[![License](https://img.shields.io/github/license/pigeonposse/super8?color=green&style=for-the-badge&logoColor=white)](/LICENSE)
[![Core](https://img.shields.io/npm/v/@s-8/core?color=blue&style=for-the-badge&logoColor=white)](https://www.npmjs.com/package/@s-8/core)
[![Super8 web](https://img.shields.io/github/package-json/v/pigeonposse/super8?filename=packages%2Fapp%2Fpackage.json?color=blue&style=for-the-badge&logoColor=white)](https://super8.pigeonposse.com/)
[![Chrome](https://img.shields.io/chrome-web-store/v/aejkinmllndkgoodkfbhfkffnebmibkd?color=blue&style=for-the-badge&logoColor=white)](https://chromewebstore.google.com/detail/super8/aejkinmllndkgoodkfbhfkffnebmibkd)
[![Mozilla](https://img.shields.io/amo/v/{63bba7f4-510b-4478-b401-a2726a9703ba}?color=blue&style=for-the-badge&logoColor=white)](https://addons.mozilla.org/es/firefox/addon/super8/)
[![Edge](https://img.shields.io/badge/dynamic/json?label=microsoft%20edge%20store&query=%24.version&url=https://microsoftedge.microsoft.com/addons/getproductdetailsbycrxid/milbmbciipbjlbjlidhgfnlkempefffi?color=blue&style=for-the-badge&logoColor=white)](https://microsoftedge.microsoft.com/addons/detail/milbmbciipbjlbjlidhgfnlkempefffi)
<!-- PIGEONPOSSE END HEADER -->

<!-- PIGEONPOSSE START INDEX -->
## Index

- [Documentation](https://docs.super8.pigeonposse.com)
- [Web version](https://super8.pigeonposse.com/)

<!-- PIGEONPOSSE END INDEX -->

<!-- PIGEONPOSSE START CONTENT -->
## 🗒 Description

🎬🎨🧩 Add styles to web video like iFrames, YouTube & Vimeo videos, Netflix, Amazon etc

[![DEMO](https://raw.githubusercontent.com/pigeonposse/super8/main/docs/images/demo-filters.png)](https://super8.pigeonposse.com/)
<!-- PIGEONPOSSE END CONTENT -->

The `@s-8/core-react` library is a collection of **React components**, specifically designed for integration with the **Super8** software. These components have been created to simplify the development of consistent and appealing user interfaces within the **Super8** application.

> The `@s-8/core-react` is a conversion of `@s-8/core` for use with **React**.

## Installation

You can install this library via npm:

```bash
npm install @s-8/core-react
// or
pnpm i @s-8/core-react
// or 
yarn add @s-8/core-react
```

## Documentation

Find detailed information about each component in [documentation](../../docs/dev-components-info.md).

<!-- PIGEONPOSSE START ORG -->
## 👨‍💻 Development

**SUPER8** is an open-source project and its development is open to anyone who wants to participate.

[![Issues](https://img.shields.io/badge/Issues-grey?style=for-the-badge)](https://github.com/pigeonposse/super8/issues)
[![Pull requests](https://img.shields.io/badge/Pulls-grey?style=for-the-badge)](https://github.com/pigeonposse/super8/pulls)
[![Read more](https://img.shields.io/badge/Read%20more-grey?style=for-the-badge)](https://super8.pigeonposse.com/)

## ☕ Donate

Help us to develop more interesting things.

[![Donate](https://img.shields.io/badge/Donate-grey?style=for-the-badge)](https://pigeonposse.com/?popup=donate)

## 📜 License

This software is licensed with **[GPL-3.0](/LICENSE)**.

[![Read more](https://img.shields.io/badge/Read-more-grey?style=for-the-badge)](/LICENSE)

## 🐦 About us

*PigeonPosse* is a ✨ **code development collective** ✨ focused on creating practical and interesting tools that help developers and users enjoy a more agile and comfortable experience. Our projects cover various programming sectors and we do not have a thematic limitation in terms of projects.

[![More](https://img.shields.io/badge/Read-more-grey?style=for-the-badge)](https://github.com/pigeonposse)

### Collaborators

|                                                                                    | Name        | Role         | GitHub                                         |
| ---------------------------------------------------------------------------------- | ----------- | ------------ | ---------------------------------------------- |
| <img src="https://pigeonposse.com.png?size=72" alt="Angelo" style="border-radius:100%"/> | Angelo |   Idea & Development & UI Design   | [@Angelo](https://pigeonposse.com) |
| <img src="https://github.com/alejomalia.png?size=72" alt="Alejo" style="border-radius:100%"/> | Alejo |  Idea & UI Concept   | [@Alejo](https://github.com/alejomalia) |
| <img src="https://github.com/PigeonPosse.png?size=72" alt="PigeonPosse" style="border-radius:100%"/> | PigeonPosse | Collective | [@PigeonPosse](https://github.com/PigeonPosse) |

<br>
<p align="center">

[![Web](https://img.shields.io/badge/Web-grey?style=for-the-badge&logoColor=white)](https://pigeonposse.com)
[![About Us](https://img.shields.io/badge/About%20Us-grey?style=for-the-badge&logoColor=white)](https://pigeonposse.com?popup=about)
[![Donate](https://img.shields.io/badge/Donate-pink?style=for-the-badge&logoColor=white)](https://pigeonposse.com/?popup=donate)
[![Github](https://img.shields.io/badge/Github-black?style=for-the-badge&logo=github&logoColor=white)](https://github.com/pigeonposse)
[![Twitter](https://img.shields.io/badge/Twitter-black?style=for-the-badge&logo=twitter&logoColor=white)](https://twitter.com/pigeonposse_)
[![Instagram](https://img.shields.io/badge/Instagram-black?style=for-the-badge&logo=instagram&logoColor=white)](https://www.instagram.com/pigeon.posse/)
[![Medium](https://img.shields.io/badge/Medium-black?style=for-the-badge&logo=medium&logoColor=white)](https://medium.com/@pigeonposse)

</p>
<!-- PIGEONPOSSE END ORG -->

==> core-react-0.1.9.tgz: package/README.md <==
<!-- PIGEONPOSSE START MARK -->
<!--
██████╗ ██╗ ██████╗ ███████╗ ██████╗ ███╗   ██╗  
██╔══██╗██║██╔════╝ ██╔════╝██╔═══██╗████╗  ██║  
██████╔╝██║██║  ███╗█████╗  ██║   ██║██╔██╗ ██║  
██╔═══╝ ██║██║   ██║██╔══╝  ██║   ██║██║╚██╗██║  
██║     ██║╚██████╔╝███████╗╚██████╔╝██║ ╚████║  
╚═╝     ╚═╝ ╚═════╝ ╚══════╝ ╚═════╝ ╚═╝  ╚═══╝  
                                                 
██████╗  ██████╗ ███████╗███████╗███████╗        
██╔══██╗██╔═══██╗██╔════╝██╔════╝██╔════╝        
██████╔╝██║   ██║███████╗███████╗█████╗          
██╔═══╝ ██║   ██║╚════██║╚════██║██╔══╝          
██║     ╚██████╔╝███████║███████║███████╗        
╚═╝      ╚═════╝ ╚══════╝╚══════╝╚══════╝        
                                                 
                                                 
                                                 
█████╗█████╗█████╗█████╗█████╗█████╗█████╗       
╚════╝╚════╝╚════╝╚════╝╚════╝╚════╝╚════╝       
                                                 
                                                 
                                                 
███████╗██╗   ██╗██████╗ ███████╗██████╗  █████╗ 
██╔════╝██║   ██║██╔══██╗██╔════╝██╔══██╗██╔══██╗
███████╗██║   ██║██████╔╝█████╗  ██████╔╝╚█████╔╝
╚════██║██║   ██║██╔═══╝ ██╔══╝  ██╔══██╗██╔══██╗
███████║╚██████╔╝██║     ███████╗██║  ██║╚█████╔╝
╚══════╝ ╚═════╝ ╚═╝     ╚══════╝╚═╝  ╚═╝ ╚════╝ 
                                                                     
                                                
REPOSITORY: https://github.com/pigeonposse/super8
AUTHORS: 
	- Angelo (https://github.com/angelespejo)

DEVELOPED BY Angelo 🐦🌈

-->
<!-- PIGEONPOSSE END MARK -->

# SUPER8 | Core & Components _(React)_

<!-- PIGEONPOSSE START HEADER -->

[![HEADER](https://raw.githubusercontent.com/pigeonposse/super8/main/docs/images/banner.png)](https://super8.pigeonposse.com/)

[![Web](https://img.shields.io/badge/Web-grey?style=for-the-badge&logoColor=white)](https://pigeonposse.com)
[![About Us](https://img.shields.io/badge/About%20Us-grey?style=for-the-badge&logoColor=white)](https://pigeonposse.com?popup=about)
[![Donate](https://img.shields.io/badge/Donate-pink?style=for-the-badge&logoColor=white)](https://pigeonposse.com/?popup=donate)
[![Github](https://img.shields.io/badge/Github-black?style=for-the-badge&logo=github&logoColor=white)](https://github.com/pigeonposse)
[![Twitter](https://img.shields.io/badge/Twitter-black?style=for-the-badge&logo=twitter&logoColor=white)](https://twitter.com/pigeonposse_)
[![Instagram](https://img.shields.io/badge/Instagram-black?style=for-the-badge&logo=instagram&logoColor=white)](https://www.instagram.com/pigeon.posse/)
[![Medium](https://img.shields.io/badge/Medium-black?style=for-the-badge&logo=medium&logoColor=white)](https://medium.com/@pigeonposse)

[![License](https://img.shields.io/github/license/pigeonposse/super8?color=green&style=for-the-badge&logoColor=white)](/LICENSE)
[![Core](https://img.shields.io/npm/v/@s-8/core?color=blue&style=for-the-badge&logoColor=white)](https://www.npmjs.com/package/@s-8/core)
[![Version](https://img.shields.io/github/package-json/v/pigeonposse/super8?filename=packages%2Fapp%2Fpackage.json?color=blue&style=for-the-badge&logoColor=white)](https://super8.pigeonposse.com/)

[![Chrome](https://img.shields.io/chrome-web-store/v/aejkinmllndkgoodkfbhfkffnebmibkd?color=blue&style=for-the-badge&logoColor=white)](https://chromewebstore.google.com/detail/super8/aejkinmllndkgoodkfbhfkffnebmibkd)
[![Mozilla](https://img.shields.io/amo/v/{63bba7f4-510b-4478-b401-a2726a9703ba}?color=blue&style=for-the-badge&logoColor=white)](https://addons.mozilla.org/es/firefox/addon/super8/)
[![Edge](https://img.shields.io/badge/dynamic/json?label=microsoft%20edge%20store&query=%24.version&url=https://microsoftedge.microsoft.com/addons/getproductdetailsbycrxid/milbmbciipbjlbjlidhgfnlkempefffi?color=blue&style=for-the-badge&logoColor=white)](https://microsoftedge.microsoft.com/addons/detail/milbmbciipbjlbjlidhgfnlkempefffi)
<!-- PIGEONPOSSE END HEADER -->

<!-- PIGEONPOSSE START INDEX -->
## Index

- [Documentation](https://docs.super8.pigeonposse.com)
- [Web version](https://super8.pigeonposse.com/)

<!-- PIGEONPOSSE END INDEX -->

<!-- PIGEONPOSSE START CONTENT -->
## 🗒 Description

🎬🎨🧩 Add styles to web video like iFrames, YouTube & Vimeo videos, Netflix, Amazon etc

[![DEMO](https://raw.githubusercontent.com/pigeonposse/super8/main/docs/images/demo-filters.gif)](https://super8.pigeonposse.com/)
<!-- PIGEONPOSSE END CONTENT -->

The `@s-8/core-react` library is a collection of **React components**, specifically designed for integration with the **Super8** software. These components have been created to simplify the development of consistent and appealing user interfaces within the **Super8** application.

> The `@s-8/core-react` is a conversion of `@s-8/core` for use with **React**.

## Installation

You can install this library via npm:

```bash
npm install @s-8/core-react
// or
pnpm i @s-8/core-react
// or 
yarn add @s-8/core-react
```

## Documentation

Find detailed information about each component in [documentation](../../docs/dev-components-info.md).

<!-- PIGEONPOSSE START ORG -->
## 👨‍💻 Development

**SUPER8** is an open-source project and its development is open to anyone who wants to participate.

[![Issues](https://img.shields.io/badge/Issues-grey?style=for-the-badge)](https://github.com/pigeonposse/super8/issues)
[![Pull requests](https://img.shields.io/badge/Pulls-grey?style=for-the-badge)](https://github.com/pigeonposse/super8/pulls)
[![Read more](https://img.shields.io/badge/Read%20more-grey?style=for-the-badge)](https://super8.pigeonposse.com/)

## ☕ Donate

Help us to develop more interesting things.

[![Donate](https://img.shields.io/badge/Donate-grey?style=for-the-badge)](https://pigeonposse.com/?popup=donate)

## 📜 License

This software is licensed with **[GPL-3.0](/LICENSE)**.

[![Read more](https://img.shields.io/badge/Read-more-grey?style=for-the-badge)](/LICENSE)

## 🐦 About us

*PigeonPosse* is a ✨ **code development collective** ✨ focused on creating practical and interesting tools that help developers and users enjoy a more agile and comfortable experience. Our projects cover various programming sectors and we do not have a thematic limitation in terms of projects.

[![More](https://img.shields.io/badge/Read-more-grey?style=for-the-badge)](https://github.com/pigeonposse)

### Collaborators

|                                                                                    | Name        | Role         | GitHub                                         |
| ---------------------------------------------------------------------------------- | ----------- | ------------ | ---------------------------------------------- |
| <img src="https://github.com/angelespejo.png?size=72" alt="Angelo" style="border-radius:100%"/> | Angelo |   Idea & Development & UI Design   | [@Angelo](https://github.com/angelespejo) |
| <img src="https://github.com/alejomalia.png?size=72" alt="Alejo" style="border-radius:100%"/> | Alejo |  Idea & UI Concept   | [@Alejo](https://github.com/alejomalia) |
| <img src="https://github.com/PigeonPosse.png?size=72" alt="PigeonPosse" style="border-radius:100%"/> | PigeonPosse | Collective | [@PigeonPosse](https://github.com/PigeonPosse) |

<br>
<p align="center">

[![Web](https://img.shields.io/badge/Web-grey?style=for-the-badge&logoColor=white)](https://pigeonposse.com)
[![About Us](https://img.shields.io/badge/About%20Us-grey?style=for-the-badge&logoColor=white)](https://pigeonposse.com?popup=about)
[![Donate](https://img.shields.io/badge/Donate-pink?style=for-the-badge&logoColor=white)](https://pigeonposse.com/?popup=donate)
[![Github](https://img.shields.io/badge/Github-black?style=for-the-badge&logo=github&logoColor=white)](https://github.com/pigeonposse)
[![Twitter](https://img.shields.io/badge/Twitter-black?style=for-the-badge&logo=twitter&logoColor=white)](https://twitter.com/pigeonposse_)
[![Instagram](https://img.shields.io/badge/Instagram-black?style=for-the-badge&logo=instagram&logoColor=white)](https://www.instagram.com/pigeon.posse/)
[![Medium](https://img.shields.io/badge/Medium-black?style=for-the-badge&logo=medium&logoColor=white)](https://medium.com/@pigeonposse)

</p>
<!-- PIGEONPOSSE END ORG -->
